<?php
# this file is meant to act as a central place to store constants.
#
# sales taxes
#$tax_rate 			= 8.75;
# does your local government require you to collect sales taxes on your labor, in addition to materials?
# possible values: 0 or 1
$is_labor_taxed		= 1;
#
?>
